@@ -5,9 +5,9 @@ from tornado.web import UIModule
 
 
 class Script(UIModule):
-    def render(self, origin, compress, *args, **kwargs):
+    def render(self, origin, compress=None, *args, **kwargs):
         cdn = self.handler.cdn
-        debug = self.handler.debug
+        debug = self.handler.js_debug
 
         js_version = self.handler.js_version
 
@@ -15,7 +15,7 @@ class Script(UIModule):
 
         buff = ''
 
-        if debug:
+        if debug or compress is None:
             if isinstance(origin, str):
                 to_show = [origin]
             else:
